pub struct Logger<F> { /* private fields */ }Expand description
The trillium handler for this crate, and the core type
Implementations
Sourceimpl Logger<()>
impl Logger<()>
Sourcepub fn new() -> Logger<impl LogFormatter>
pub fn new() -> Logger<impl LogFormatter>
Builds a new logger
Defaults:
- formatter:
dev_formatter - color mode:
ColorMode::Auto - target:
Target::Stdout
Sourceimpl<T> Logger<T>
impl<T> Logger<T>
Sourcepub fn with_formatter<Formatter: LogFormatter>(
self,
formatter: Formatter,
) -> Logger<Formatter>
pub fn with_formatter<Formatter: LogFormatter>( self, formatter: Formatter, ) -> Logger<Formatter>
replace the formatter with any type that implements LogFormatter
see the trait documentation for LogFormatter for more details. note that this can be
chained with Logger::with_target and Logger::with_color_mode
use trillium_logger::{Logger, apache_common};
Logger::new().with_formatter(apache_common("-", "-"));Sourceimpl<F: LogFormatter> Logger<F>
impl<F: LogFormatter> Logger<F>
Sourcepub fn with_color_mode(self, color_mode: ColorMode) -> Self
pub fn with_color_mode(self, color_mode: ColorMode) -> Self
specify the color mode for this logger.
see ColorMode for more details. note that this can be chained
with Logger::with_target and Logger::with_formatter
use trillium_logger::{ColorMode, Logger};
Logger::new().with_color_mode(ColorMode::On);Sourcepub fn with_target(self, target: impl Targetable) -> Self
pub fn with_target(self, target: impl Targetable) -> Self
specify the logger target
see Target for more details. note that this can be chained
with Logger::with_color_mode and Logger::with_formatter
use trillium_logger::{Logger, Target};
Logger::new().with_target(Target::Logger(log::Level::Info));Trait Implementations
Sourceimpl<F> Handler for Logger<F>where
F: LogFormatter,
impl<F> Handler for Logger<F>where
F: LogFormatter,
Sourceasync fn init(&mut self, info: &mut Info)
async fn init(&mut self, info: &mut Info)
Performs one-time async set up on a mutable borrow of the Handler before the server starts
accepting requests. This allows a Handler to be defined in synchronous code but perform
async setup such as establishing a database connection or fetching some state from an
external source. This is optional, and chances are high that you do not need this. Read more
Sourceasync fn run(&self, conn: Conn) -> Conn
async fn run(&self, conn: Conn) -> Conn
Executes this handler, performing any modifications to the Conn that are desired.
Sourceasync fn before_send(&self, conn: Conn) -> Conn
async fn before_send(&self, conn: Conn) -> Conn
Performs any final modifications to this conn after all handlers have been run. Although
this is a slight deviation from the simple conn->conn->conn chain represented by most
Handlers, it provides an easy way for libraries to effectively inject a second handler into
a response chain. This is useful for loggers that need to record information both before and
after other handlers have run, as well as database transaction handlers and similar library
code. Read more
Sourcefn has_upgrade(&self, upgrade: &Upgrade) -> bool
fn has_upgrade(&self, upgrade: &Upgrade) -> bool
predicate function answering the question of whether this Handler would like to take
ownership of the negotiated Upgrade. If this returns true, you must implement
Handler::upgrade. The first handler that responds true to this will receive
ownership of the trillium::Upgrade in a subsequent call to
Handler::upgradeSourcefn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
fn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
This will only be called if the handler reponds true to
Handler::has_upgrade and will
only be called once for this upgrade. There is no return value, and this function takes
exclusive ownership of the underlying transport once this is called. You can downcast
the transport to whatever the source transport type is and perform any non-http protocol
communication that has been negotiated. You probably don’t want this unless you’re
implementing something like websockets. Please note that for many transports such as
TcpStreams, dropping the transport (and therefore the Upgrade) will hang up /
disconnect.Auto Trait Implementations
impl<F> Freeze for Logger<F>where
F: Freeze,
impl<F> !RefUnwindSafe for Logger<F>
impl<F> Send for Logger<F>where
F: Send,
impl<F> Sync for Logger<F>where
F: Sync,
impl<F> Unpin for Logger<F>where
F: Unpin,
impl<F> UnsafeUnpin for Logger<F>where
F: UnsafeUnpin,
impl<F> !UnwindSafe for Logger<F>